@@ -1,11 +1,11 @@
-"""Utilitarian Python ORM for Postgres, backed by asyncpg, Pydantic, and PyPika"""
+"""Utilitarian Python ORM for Postgres/SQLite, backed by asyncpg/aiosqlite, Pydantic, and PyPika"""
 
-__version__ = "0.5.0"
+__version__ = "0.6.0"
 
 # Provided for convenience
 from pypika import Order
 
-from .core import *
+from .core import postgres, querybuilder, sqlite
 from .exceptions import *
 from .fields import *
 from .table import *
